@@ -13,15 +13,15 @@ PenalizedRegressionBasedClustering=function(Data,FirstLambda,SecondLambda,Tau, P
   # Object            Object of prclust::PRclust algorithm
   #
   # Author: MT
-  if (!requireNamespace('prclust')) {
+  if (!requireNamespace('prclust',quietly = TRUE)) {
     message(
-      'Subordinate clustering package is missing. No computations are performed.
+      'Subordinate clustering package (prclust) is missing. No computations are performed.
             Please install the package which is defined in "Suggests".'
     )
     return(
       list(
         Cls = rep(1, nrow(Data)),
-        Object = "Subordinate clustering package is missing.
+        Object = "Subordinate clustering package (prclust) is missing.
                 Please install the package which is defined in 'Suggests'."
       )
     )
